# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/nymstr',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/nymstr',
                'lib_path': 'nymstr'},
  'syms': { 'nymstr.core': { 'nymstr.core.nymstr': ('core.html#nymstr', 'nymstr/core.py'),
                             'nymstr.core.nymstr.__eq__': ('core.html#nymstr.__eq__', 'nymstr/core.py'),
                             'nymstr.core.nymstr.__new__': ('core.html#nymstr.__new__', 'nymstr/core.py'),
                             'nymstr.core.nymstr.__repr__': ('core.html#nymstr.__repr__', 'nymstr/core.py'),
                             'nymstr.core.nymstr.copy': ('core.html#nymstr.copy', 'nymstr/core.py'),
                             'nymstr.core.nymstr.isitem': ('core.html#nymstr.isitem', 'nymstr/core.py'),
                             'nymstr.core.nymstr.item': ('core.html#nymstr.item', 'nymstr/core.py'),
                             'nymstr.core.nymstr.snake': ('core.html#nymstr.snake', 'nymstr/core.py')},
            'nymstr.snake': { 'nymstr.snake.joinall': ('snake.html#joinall', 'nymstr/snake.py'),
                              'nymstr.snake.py_to_snake': ('snake.html#py_to_snake', 'nymstr/snake.py'),
                              'nymstr.snake.swapall': ('snake.html#swapall', 'nymstr/snake.py'),
                              'nymstr.snake.to_snake': ('snake.html#to_snake', 'nymstr/snake.py')}}}
